@@ -10,7 +10,7 @@ use LWP::Protocol::socks;
 use HTTP::Request::Common;
 use URI::Simple;
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use constant {
 	HTTP_PROXY => 'http',
@@ -160,7 +160,7 @@ WebService::Gyazo::B - a Perl image upload library for gyazo.com
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -200,12 +200,13 @@ Parameter id is optional, if the parameter is not passed, it will take the value
 
 	my $proxy = 'http://1.2.3.4:8080';
 	if ($wsd->setProxy($proxy)) {
-		print "Proxy [".$proxy."] seted!";
+		print "The proxy [$proxy] was set!";
 	} else {
-		print "Proxy not seted! Error [".$wsd->error."]";
+		print "The proxy was not set! Error [".$wsd->error."]";
 	}
 
-Set proxy C<1.2.3.4:8080> and protocol http for C<LWP::UserAgent> object.
+Set the proxy C<1.2.3.4:8080> and the protocol http for the C<LWP::UserAgent>
+object.
 
 =head2 C<error>
 
